@@ -46,13 +46,15 @@ from ..tables import (
     scoreboard_table,
     user_table,
     api_key_table,
-    statistic_table
+    statistic_table,
+    server_table
 )
 
 from ..exceptions import (
     InvalidCommunity,
     InvalidSteamID,
-    UserExists
+    UserExists,
+    ServerExists
 )
 
 from .models import (
@@ -60,13 +62,15 @@ from .models import (
     MatchModel,
     ProfileModel,
     CommunityStatsModel,
-    PublicCommunityModel
+    PublicCommunityModel,
+    ServerModel
 )
 
 from ..user import create_user
 
 from .key import Key
 from .match import Match
+from .server import Server
 
 
 class Community:
@@ -81,6 +85,78 @@ class Community:
 
         self.community_name = community_name
 
+    async def create_server(self, ip: str, port: int,
+                            name: str) -> Tuple[ServerModel, Server]:
+        """Used to create server.
+
+        Parameters
+        ----------
+        ip : str
+        port : int
+        name : str
+
+        Returns
+        -------
+        ServerModel
+        Server
+
+        Raises
+        ------
+        ServerExists
+        """
+
+        values = dict(
+            community_name=self.community_name,
+            ip=ip,
+            port=port,
+            name=name,
+            players=0,
+            max_players=0,
+            map=None
+        )
+
+        try:
+            await Sessions.database.execute(
+                server_table.insert().values(
+                    **values
+                )
+            )
+        except Exception:
+            raise ServerExists()
+        else:
+            return ServerModel(**values), self.server(ip, port)
+
+    async def servers(self) -> AsyncGenerator[ServerModel, Server]:
+        """Used to list servers.
+
+        Yields
+        -------
+        ServerModel
+        Server
+        """
+
+        query = server_table.select().where(
+            server_table.c.community_name == self.community_name
+        )
+
+        async for row in Sessions.database.iterate(query):
+            yield ServerModel(**row), self.server(row["ip"], row["port"])
+
+    def server(self, ip: str, port: int) -> Server:
+        """Used to interact with a server.
+
+        Parameters
+        ----------
+        ip : str
+        port : int
+
+        Returns
+        -------
+        Server
+        """
+
+        return Server(ip, port, self.community_name)
+
     async def email(self, title: str, content: str,
                     link_href: str, link_text: str) -> None:
         """Used to send email to community owner.
